@@ -2,6 +2,7 @@ from napoleontoolbox.utility import date_utility
 import pandas as pd
 import numpy as np
 from napoleontoolbox.utility import metrics
+import operator
 
 def past_volatility(x):
     return np.sqrt(252)*np.std(x)
@@ -40,12 +41,7 @@ def vol_target_indice_rebalancing(weight_data=None, vol_target = None, volatilit
     return target_vol_values_df
 
 def vol_capped_indice_rebalancing(weight_data=None, target_weights = None, vol_cap = None, volatility_window = 252, vol_cap_inception_date = None, initial_value = 100.):
-    #vol < 25.7 % (target / 0.35) = > 30 %
-    #vol < 30 % = > 25 %
-    #vol < 36 % = > 20 %
-
-    max_size_constituent = max(target_weights, key=d.get)
-
+    max_size_constituent = max(target_weights.iteritems(), key=operator.itemgetter(1))[0]
     assert vol_cap is not None
     weight_data['indice_returns'] = weight_data['indice'].pct_change()
     weight_data['rolling_vol_indice'] = weight_data['indice_returns'].rolling(volatility_window).apply(past_volatility)
@@ -202,7 +198,12 @@ def to_euro(weight_data = None, rates_data = None):
     data['indice'] = data['indice_eur']
     return data
 
-
+def to_hedged_euro(weight_data = None, rates_data = None):
+    data = join_forex_data(weight_data = weight_data, rates_data = rates_data)
+    data['indice_usd'] = data['indice']
+    data['indice_eur'] = data['indice_usd']/data['EUR-USD']
+    data['indice'] = data['indice_eur']
+    return data
 
 
 
