@@ -16,7 +16,7 @@ import json
 
 from pathlib import Path
 
-def daily_bc_apply_standard_mean_two_states_discretization(signals_df=None, s=21):
+def daily_bc_apply_standard_mean_discretization(signals_df=None, s=21, method ='find_best_three_states_discretization_lo'):
     day_signal_columns = [me_sig for me_sig in signals_df.columns if 'signal' in me_sig ]
     signals_np = signals_df[day_signal_columns].values  # [:, len(self.generic_columns):]
     full_y_true = signals_df['close'].pct_change().fillna(0.)
@@ -28,10 +28,31 @@ def daily_bc_apply_standard_mean_two_states_discretization(signals_df=None, s=21
         rolling_np = signals_np[starting_train:stopping_train, :]
         y_train_true = full_y_true[starting_train:stopping_train]
         y_train_pred = np.mean(rolling_np, axis=1)
-        splitting_quantile_threshold, splitting_threshold, sharpe_strat, sharpe_under = signal_utility.find_best_two_states_discretization(
-            y_train_pred, y_train_true)
-        y_next_pred = np.nanmean(signals_np[row_index, :])
-        y_next_pred_discrete = signal_utility.apply_discretization_two_states(y_next_pred, splitting_threshold)
+
+        if method == 'find_best_three_states_discretization':
+            lower_quantile_threshold, upper_quantile_threshold, lower_threshold, upper_threshold, sharpe_strat, sharpe_under = signal_utility.find_best_three_states_discretization(
+                y_train_pred, y_train_true)
+            y_next_pred = np.nanmean(signals_np[row_index, :])
+            y_next_pred_discrete = signal_utility.apply_discretization_three_states(y_next_pred, upper_threshold,
+                                                                                    lower_threshold)
+        elif method == 'find_best_three_states_discretization_lo':
+            lower_quantile_threshold, upper_quantile_threshold, lower_threshold, upper_threshold, sharpe_strat, sharpe_under = signal_utility.find_best_three_states_discretization_lo(
+                y_train_pred, y_train_true)
+            y_next_pred = np.nanmean(signals_np[row_index, :])
+            y_next_pred_discrete = signal_utility.apply_discretization_three_states_lo(y_next_pred, upper_threshold,
+                                                                                       lower_threshold)
+        elif method == 'find_best_two_states_discretization':
+            splitting_quantile_threshold, splitting_threshold, sharpe_strat, sharpe_under = signal_utility.find_best_two_states_discretization(
+                y_train_pred, y_train_true)
+
+            y_next_pred = np.nanmean(signals_np[row_index, :])
+            y_next_pred_discrete = signal_utility.apply_discretization_two_states(y_next_pred, splitting_threshold)
+        elif method == 'find_best_two_states_discretization_lo':
+            splitting_quantile_threshold, splitting_threshold, sharpe_strat, sharpe_under = signal_utility.find_best_two_states_discretization_lo(
+                y_train_pred, y_train_true)
+            y_next_pred = np.nanmean(signals_np[row_index, :])
+            y_next_pred_discrete = signal_utility.apply_discretization_two_states_lo(y_next_pred, splitting_threshold)
+
         y_pred_discretized[prediction] = y_next_pred_discrete
     return y_pred_discretized
 
@@ -52,8 +73,10 @@ class AbstractRunner(ABC):
         self.algo=algo
         self.selected_algo=selected_algo
 
-        self.dates_stub = self.calibration_starting_date.strftime('%d_%b_%Y') + '_' + self.calibration_running_date.strftime('%d_%b_%Y')
-        self.list_pkl_file_name = self.dates_stub +'_' +self.underlying + '_' + self.frequence + '_' + self.selected_algo + self.list_pkl_file_suffix
+        self.calibrating_dates_stub = self.calibration_starting_date.strftime('%d_%b_%Y') + '_' + self.calibration_running_date.strftime('%d_%b_%Y')
+        self.dates_stub = self.starting_date.strftime('%d_%b_%Y') + '_' + self.running_date.strftime('%d_%b_%Y')
+
+        self.list_pkl_file_name = self.calibrating_dates_stub +'_' +self.underlying + '_' + self.frequence + '_' + self.selected_algo + self.list_pkl_file_suffix
         self.aggregated_pkl_file_name = self.dates_stub +'_' + self.underlying + '_' + self.frequence + '_' + self.selected_algo + self.aggregated_pkl_file_suffix
         self.aggregated_pkl_mapping_file_name = self.dates_stub +'_'+ self.underlying + '_' + self.frequence + '_' + self.selected_algo + self.aggregated_pkl_mapping_file_suffix
 
@@ -273,7 +296,7 @@ class AggregatingSignalRunner(AbstractRunner):
 
     def saving_cumulated_signals(self, cumulated_signals_df, mapping_dictionary):
         print('discretizing the cumulated signals using ia')
-        discrete_daily_signals = daily_bc_apply_standard_mean_two_states_discretization(signals_df=cumulated_signals_df, s=self.daily_ia_lookback_window)
+        discrete_daily_signals = daily_bc_apply_standard_mean_discretization(signals_df=cumulated_signals_df, s=self.daily_ia_lookback_window)
         cumulated_signals_df['trend']=discrete_daily_signals
         print(f'discretization done {len(discrete_daily_signals)}')
         print('saving to ' + self.aggregated_pkl_file_name)
